# anthologia-site

## Deployed instances

Production (`production` branch, manual):
https://anthologiagraeca.org/

Pre-production (`preprod` branch, manual):
https://preprod.anthologiagraeca.org/


## Requirements

* [uv](https://docs.astral.sh/uv/getting-started/installation/)
* PostgreSQL 14
* PostGIS 
* make

## Setup

### Development deployment

#### Install Database (Postgres) and db management

##### With apt
`sudo apt install libpq-dev postgresql postgresql-contrib postgis`

##### With Homebrew
`brew install postgresql@14`
`brew install  postgis`

#### Connect to database :
```
    sudo su postgres (login as the user "postgres", if normal user havent the right to access the database)
    psql
```

* Create database ([doc](https://www.digitalocean.com/community/tutorials/how-to-use-postgresql-with-your-django-application-on-ubuntu-14-04)) and configure for django:
 ```
    CREATE DATABASE anthology;
    CREATE USER anthology_django WITH PASSWORD 'password';
    ALTER ROLE anthology_django SET client_encoding TO 'utf8';
    ALTER ROLE anthology_django SET default_transaction_isolation TO 'read committed';
    ALTER ROLE anthology_django SET timezone TO 'UTC-4';
    ALTER USER anthology_django CREATEDB;
    GRANT ALL PRIVILEGES ON DATABASE anthology TO anthology_django;
    CREATE EXTENSION postgis;
```

* (Optional) Drop database
When updating the schema, before running `makemigration` having no data yet, you want to drop existing db to 
recreate it.

 ```
    psql
    DROP DATABASE anthology;
    CREATE DATABASE anthology;
    GRANT ALL PRIVILEGES ON DATABASE anthology TO anthology_django;
```

* ONLY FOR TESTING ENV:
```
ALTER ROLE anthology_django SUPERUSER;
```

#### Setup environment

Install uv and the dependencies:
* Follow [uv documentation](https://docs.astral.sh/uv/getting-started/installation/#standalone-installer) to install uv
* Go to the repo folder `cd anthologia-site`
* Install dependencies `uv sync --dev`

Install make:
* `brew install make`

#### Running server

 * (apply migrations) `uv run django/manage.py migrate --settings=anthology.settings.local`
 * (compile messages) `DJANGO_SETTINGS_MODULE=anthology.settings.local uv run django/manage.py compilemessages`
 * `make run`

#### Updating the model

* make change in the `django/meleager/models` folder
* run `uv run django/manage.py makemigrations --settings=anthology.settings.local`
* run `uv run django/manage.py migrate --settings=anthology.settings.local`

#### Translate strings
* `DJANGO_SETTINGS_MODULE=anthology.settings.local uv run django/manage.py makemessages --all`
* check `django/locale/` files
* compilemessages  `DJANGO_SETTINGS_MODULE=anthology.settings.local uv run django/manage.py compilemessages`

#### Install new packages
* `uv add NewPackage`
* Check `pyproject.toml` file
* Generate a new `uv.lock` file with `uv lock` command

#### Run tests
* `make tests`

### Manual installation (macOS)

Check out code from the git repository:

    $ git clone git@gitlab.huma-num.fr:ecrinum/anthologia/anthologia-site.git
    $ cd anthologia-site

Switch to the `preprod` branch (or create a new dedicated branch for your developments).

Install uv:
    $ brew install uv

Install and launch PostgreSQL (with homebrew, YMMV):

    $ brew install postgres@14
    $ brew install postgis
    $ brew services start postgresql

You can check the database is ready:

    $ pg_isready

Set useful env variables:

    $ export POSTGRES_DB=anthology
    $ export POSTGRES_USER=anthology_django
    $ export POSTGRES_PASSWORD=password

Create relevant user and database:

    $ createuser $POSTGRES_USER
    $ createdb $POSTGRES_DB --owner=$POSTGRES_USER

You must be an admin (`david` in my case) to perform these operations:

    $ psql --username "david" --dbname "$POSTGRES_DB"
    =# ALTER USER "anthology_django" CREATEDB;
    =# CREATE EXTENSION postgis;

You can check the list of DBs with `\l` and roles with `\du`.

Set database options:

    $ psql --username "$POSTGRES_USER" --dbname "$POSTGRES_DB"
    => ALTER ROLE "anthology_django" SET client_encoding TO 'utf8';
    => ALTER ROLE "anthology_django" SET default_transaction_isolation TO 'read committed';
    => ALTER ROLE "anthology_django" SET timezone TO 'UTC-4';
    => GRANT ALL PRIVILEGES ON DATABASE "anthology" TO "anthology_django";

Download the latest DB dump from https://gitlab.huma-num.fr/ecrinum/BaseAP/ and load it:

    $ psql $POSTGRES_DB < ap-prod-db.sql

Optionally run migrations (if any new ones on your branch):

    $  uv run django/manage.py migrate --settings=anthology.settings.local

Create an editor user to interact with your local instance:

    $ uv run django/manage.py shell_plus --settings=anthology.settings.local
    >>> user = User.objects.create_user(username='david', email='david@example.org', password='password')
    >>> perm_can_add = Permission.objects.get(codename="can_add_mlgr")
    >>> perm_own_passages = Permission.objects.get(codename="manage_own_passages")
    >>> perm_own_mlgr = Permission.objects.get(codename="manage_own_mlgr")
    >>> editors, _ = Group.objects.get_or_create(name="Editors")
    >>> editors.permissions.add(perm_own_passages, perm_own_mlgr, perm_can_add)
    >>> user.groups.add(editors)

Reset the admin password to be able to access the administration interface:

    $  uv run django/manage.py shell_plus --settings=anthology.settings.local
    >>> admin = User.objects.all()[0]
    >>> admin.set_password("password")
    >>> admin.save()

Or create a new superuser:

    $  uv run django/manage.py createsuperuser --settings=anthology.settings.local

You should be good to go!

    $ make run
