# Generated by Django 3.1.1 on 2021-04-01 06:05

from django.conf import settings
import django.contrib.postgres.fields.ranges
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import django_extensions.db.fields.json


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Author',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('unique_id', models.IntegerField(blank=True, db_index=True, unique=True)),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('validation', models.IntegerField(choices=[(0, 'Validation level 0, see ValidationLevelName.validation_level = 0 for the validation level name.'), (1, 'Validation level 1, see ValidationLevelName.validation_level = 1 for the validation level name.')], default=0, help_text='The current validation level of this resource.')),
                ('tlg_id', models.CharField(blank=True, db_index=True, max_length=10, null=True)),
                ('born_range_year_date', django.contrib.postgres.fields.ranges.IntegerRangeField(blank=True, help_text='The date range for the author born date.', null=True)),
                ('died_range_year_date', django.contrib.postgres.fields.ranges.IntegerRangeField(blank=True, help_text='The date range for the author dead date.', null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='AuthorPassage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('timestamp', models.DateTimeField(auto_now=True, verbose_name='timestamp')),
                ('author', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='meleager.author')),
            ],
        ),
        migrations.CreateModel(
            name='Book',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('number', models.IntegerField(db_index=True, verbose_name='Book number')),
                ('creator', models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_book_creator', related_query_name='meleager_books_creator', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='City',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('unique_id', models.IntegerField(blank=True, db_index=True, unique=True)),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('longitude', models.DecimalField(blank=True, decimal_places=5, default=None, max_digits=9, null=True)),
                ('latitude', models.DecimalField(blank=True, decimal_places=5, default=None, max_digits=9, null=True)),
                ('creator', models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_city_creator', related_query_name='meleager_citys_creator', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name_plural': 'cities',
            },
        ),
        migrations.CreateModel(
            name='Comment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('unique_id', models.IntegerField(blank=True, db_index=True, unique=True)),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('comment_type', models.CharField(choices=[('user_note', 'A note by an user')], db_index=True, default='user_note', max_length=20)),
                ('creator', models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_comment_creator', related_query_name='meleager_comments_creator', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CommentTextAnchor',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('anchor_word', models.CharField(default=' ', max_length=255)),
                ('occurrence', models.IntegerField(default=0)),
                ('comment', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='meleager.comment')),
            ],
        ),
        migrations.CreateModel(
            name='Description',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('description', models.TextField(blank=True, default='')),
                ('creator', models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_description_creator', related_query_name='meleager_descriptions_creator', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Edition',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('edition_type', models.IntegerField(choices=[(0, 'Manuscript'), (1, 'Translation'), (2, 'Commentary'), (3, 'Scholia'), (4, 'Alignment')])),
                ('metadata', models.JSONField(default=dict, verbose_name='Metadata for Edition')),
                ('creator', models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_edition_creator', related_query_name='meleager_editions_creator', to=settings.AUTH_USER_MODEL)),
                ('descriptions', models.ManyToManyField(help_text='The multilingual descriptions for this object.', related_name='meleager_edition', related_query_name='meleager_editions', to='meleager.Description')),
                ('last_editor', models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_edition_last_editor', related_query_name='meleager_editions_last_editor', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ExternalReference',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=255)),
                ('url', models.URLField()),
            ],
        ),
        migrations.CreateModel(
            name='Keyword',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('unique_id', models.IntegerField(blank=True, db_index=True, unique=True)),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Language',
            fields=[
                ('code', models.CharField(max_length=3, primary_key=True, serialize=False, verbose_name='Language code (ISO639)')),
                ('iso_name', models.CharField(max_length=100, verbose_name='Language name')),
                ('preferred', models.BooleanField(db_index=True, default=False, verbose_name='Favorite language')),
            ],
            options={
                'ordering': ('-preferred', 'code'),
            },
        ),
        migrations.CreateModel(
            name='Manuscript',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('title', models.CharField(max_length=255)),
                ('url', models.URLField(help_text='The URL of this image', max_length=500)),
                ('credit', models.CharField(blank=True, default='', max_length=255)),
                ('creator', models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_manuscript_creator', related_query_name='meleager_manuscripts_creator', to=settings.AUTH_USER_MODEL)),
                ('descriptions', models.ManyToManyField(help_text='The multilingual descriptions for this object.', related_name='meleager_manuscript', related_query_name='meleager_manuscripts', to='meleager.Description')),
                ('keywords', models.ManyToManyField(help_text='The keywords that tag this resource.', related_name='manuscripts', to='meleager.Keyword')),
                ('last_editor', models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_manuscript_last_editor', related_query_name='meleager_manuscripts_last_editor', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Medium',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('unique_id', models.IntegerField(blank=True, db_index=True, unique=True)),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('type', models.CharField(choices=[('image', 'Image'), ('video', 'Video'), ('audio', 'Audio')], default='image', max_length=8)),
                ('url', models.URLField(help_text='The URL of this image', max_length=500)),
                ('creator', models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_medium_creator', related_query_name='meleager_mediums_creator', to=settings.AUTH_USER_MODEL)),
                ('descriptions', models.ManyToManyField(help_text='The multilingual descriptions for this object.', related_name='meleager_medium', related_query_name='meleager_mediums', to='meleager.Description')),
                ('keywords', models.ManyToManyField(help_text='The keywords that tag this resource.', related_name='media', to='meleager.Keyword')),
                ('last_editor', models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_medium_last_editor', related_query_name='meleager_mediums_last_editor', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Passage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('unique_id', models.IntegerField(blank=True, db_index=True, unique=True)),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('validation', models.IntegerField(choices=[(0, 'Validation level 0, see ValidationLevelName.validation_level = 0 for the validation level name.'), (1, 'Validation level 1, see ValidationLevelName.validation_level = 1 for the validation level name.')], default=0, help_text='The current validation level of this resource.')),
                ('fragment', models.IntegerField(db_index=True, help_text='The fragment number in book.')),
                ('sub_fragment', models.CharField(blank=True, db_index=True, default='', help_text='The sub fragment number in book.', max_length=3)),
            ],
            options={
                'permissions': [('manage_own_passages', 'Can manage (edit/delete) their own Passage items'), ('manage_all_passages', 'Can manage (edit/delete) all Passage items')],
            },
        ),
        migrations.CreateModel(
            name='Text',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('unique_id', models.IntegerField(blank=True, db_index=True, unique=True)),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('validation', models.IntegerField(choices=[(0, 'Validation level 0, see ValidationLevelName.validation_level = 0 for the validation level name.'), (1, 'Validation level 1, see ValidationLevelName.validation_level = 1 for the validation level name.')], default=0, help_text='The current validation level of this resource.')),
                ('status', models.IntegerField(choices=[(0, 'Draft'), (1, 'Published'), (2, 'Deleted')], default=1)),
                ('text', models.TextField(help_text='The string of this text')),
                ('comments', models.ManyToManyField(help_text='The comments of this resource.', related_name='texts', through='meleager.CommentTextAnchor', to='meleager.Comment')),
                ('creator', models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_text_creator', related_query_name='meleager_texts_creator', to=settings.AUTH_USER_MODEL)),
                ('edition', models.ForeignKey(blank=True, help_text='The edition of this text.', null=True, on_delete=django.db.models.deletion.CASCADE, to='meleager.edition')),
                ('language', models.ForeignKey(default='und', on_delete=django.db.models.deletion.SET_DEFAULT, to='meleager.language')),
                ('last_editor', models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_text_last_editor', related_query_name='meleager_texts_last_editor', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='URN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('source', models.CharField(blank=True, default='', max_length=255)),
                ('urn', models.URLField(db_index=True, unique=True)),
            ],
        ),
        migrations.CreateModel(
            name='ValidationLevelName',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('validation_level', models.IntegerField(choices=[(0, 'Validation level 0, see ValidationLevelName.validation_level = 0 for the validation level name.'), (1, 'Validation level 1, see ValidationLevelName.validation_level = 1 for the validation level name.')], help_text='The validation level integer associated with name', unique=True)),
                ('rank', models.IntegerField()),
                ('name', models.TextField(help_text='The name of this validation level', unique=True)),
            ],
        ),
        migrations.CreateModel(
            name='Work',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('alternative_urns', models.ManyToManyField(to='meleager.URN')),
                ('creator', models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_work_creator', related_query_name='meleager_works_creator', to=settings.AUTH_USER_MODEL)),
                ('descriptions', models.ManyToManyField(help_text='Descriptions for the work.', related_name='works', to='meleager.Description')),
                ('last_editor', models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_work_last_editor', related_query_name='meleager_works_last_editor', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TextPassage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('timestamp', models.DateTimeField(auto_now=True, verbose_name='timestamp')),
                ('passage', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='meleager.passage')),
                ('text', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='meleager.text')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='Scholium',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('unique_id', models.IntegerField(blank=True, db_index=True, unique=True)),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('validation', models.IntegerField(choices=[(0, 'Validation level 0, see ValidationLevelName.validation_level = 0 for the validation level name.'), (1, 'Validation level 1, see ValidationLevelName.validation_level = 1 for the validation level name.')], default=0, help_text='The current validation level of this resource.')),
                ('number', models.IntegerField(db_index=True, null=True, verbose_name='Scholium ID')),
                ('alternative_urns', models.ManyToManyField(to='meleager.URN')),
                ('city', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='scholia', to='meleager.city')),
                ('comments', models.ManyToManyField(blank=True, help_text='The comments of this resource.', related_name='scholia', to='meleager.Comment')),
                ('creator', models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_scholium_creator', related_query_name='meleager_scholiums_creator', to=settings.AUTH_USER_MODEL)),
                ('descriptions', models.ManyToManyField(help_text='The multilingual descriptions for this object.', related_name='meleager_scholium', related_query_name='meleager_scholiums', to='meleager.Description')),
                ('images', models.ManyToManyField(blank=True, help_text='The images associated to this resource.', related_name='scholia', to='meleager.Medium')),
                ('keywords', models.ManyToManyField(blank=True, help_text='The keywords that tag this resource.', related_name='scholia', to='meleager.Keyword')),
                ('last_editor', models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_scholium_last_editor', related_query_name='meleager_scholiums_last_editor', to=settings.AUTH_USER_MODEL)),
                ('manuscripts', models.ManyToManyField(blank=True, help_text='The image of the manuscript for this passage.', to='meleager.Manuscript')),
                ('passage', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='scholia', to='meleager.passage')),
                ('texts', models.ManyToManyField(help_text='Text for this scholium', related_name='scholia', to='meleager.Text')),
            ],
            options={
                'verbose_name_plural': 'Scholia',
            },
        ),
        migrations.AddField(
            model_name='passage',
            name='alternative_urns',
            field=models.ManyToManyField(to='meleager.URN'),
        ),
        migrations.AddField(
            model_name='passage',
            name='authors',
            field=models.ManyToManyField(related_name='passages', through='meleager.AuthorPassage', to='meleager.Author'),
        ),
        migrations.AddField(
            model_name='passage',
            name='book',
            field=models.ForeignKey(help_text='Book the passage is in', on_delete=django.db.models.deletion.CASCADE, related_name='passages', to='meleager.book'),
        ),
        migrations.AddField(
            model_name='passage',
            name='cities',
            field=models.ManyToManyField(related_name='passages', to='meleager.City'),
        ),
        migrations.AddField(
            model_name='passage',
            name='comments',
            field=models.ManyToManyField(help_text='The comments of this resource.', related_name='passages', to='meleager.Comment'),
        ),
        migrations.AddField(
            model_name='passage',
            name='creator',
            field=models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_passage_creator', related_query_name='meleager_passages_creator', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='passage',
            name='descriptions',
            field=models.ManyToManyField(help_text='The multilingual descriptions for this object.', related_name='meleager_passage', related_query_name='meleager_passages', to='meleager.Description'),
        ),
        migrations.AddField(
            model_name='passage',
            name='external_references',
            field=models.ManyToManyField(related_name='passages', to='meleager.ExternalReference'),
        ),
        migrations.AddField(
            model_name='passage',
            name='images',
            field=models.ManyToManyField(help_text='The images associated to this resource.', related_name='passages', to='meleager.Medium'),
        ),
        migrations.AddField(
            model_name='passage',
            name='internal_references',
            field=models.ManyToManyField(related_name='_passage_internal_references_+', to='meleager.Passage'),
        ),
        migrations.AddField(
            model_name='passage',
            name='keywords',
            field=models.ManyToManyField(blank=True, help_text='The keywords that tag this resource.', related_name='passages', to='meleager.Keyword'),
        ),
        migrations.AddField(
            model_name='passage',
            name='last_editor',
            field=models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_passage_last_editor', related_query_name='meleager_passages_last_editor', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='passage',
            name='manuscripts',
            field=models.ManyToManyField(help_text='The image of the manuscript for this passage.', related_name='passages', to='meleager.Manuscript'),
        ),
        migrations.AddField(
            model_name='passage',
            name='texts',
            field=models.ManyToManyField(help_text='Text for this passage', related_name='passages', through='meleager.TextPassage', to='meleager.Text'),
        ),
        migrations.CreateModel(
            name='Name',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('name', models.TextField()),
                ('creator', models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_name_creator', related_query_name='meleager_names_creator', to=settings.AUTH_USER_MODEL)),
                ('language', models.ForeignKey(default='und', on_delete=django.db.models.deletion.SET_DEFAULT, to='meleager.language')),
                ('last_editor', models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_name_last_editor', related_query_name='meleager_names_last_editor', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='KeywordCategory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('unique_id', models.IntegerField(blank=True, db_index=True, unique=True)),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('creator', models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_keywordcategory_creator', related_query_name='meleager_keywordcategorys_creator', to=settings.AUTH_USER_MODEL)),
                ('last_editor', models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_keywordcategory_last_editor', related_query_name='meleager_keywordcategorys_last_editor', to=settings.AUTH_USER_MODEL)),
                ('names', models.ManyToManyField(help_text='The multilingual names for this object.', related_name='keyword_categories', to='meleager.Name')),
            ],
            options={
                'verbose_name_plural': 'Keyword categories',
            },
        ),
        migrations.AddField(
            model_name='keyword',
            name='category',
            field=models.ForeignKey(help_text='The category this keyword belongs to.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='keywords', to='meleager.keywordcategory'),
        ),
        migrations.AddField(
            model_name='keyword',
            name='creator',
            field=models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_keyword_creator', related_query_name='meleager_keywords_creator', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='keyword',
            name='last_editor',
            field=models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_keyword_last_editor', related_query_name='meleager_keywords_last_editor', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='keyword',
            name='names',
            field=models.ManyToManyField(help_text='The multilingual names for this object.', related_name='keywords', to='meleager.Name'),
        ),
        migrations.CreateModel(
            name='Editor',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('creator', models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_editor_creator', related_query_name='meleager_editors_creator', to=settings.AUTH_USER_MODEL)),
                ('descriptions', models.ManyToManyField(help_text='The multilingual descriptions for this object.', related_name='meleager_editor', related_query_name='meleager_editors', to='meleager.Description')),
                ('last_editor', models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_editor_last_editor', related_query_name='meleager_editors_last_editor', to=settings.AUTH_USER_MODEL)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='edition',
            name='work',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='editions', to='meleager.work'),
        ),
        migrations.AddField(
            model_name='description',
            name='language',
            field=models.ForeignKey(default='und', on_delete=django.db.models.deletion.SET_DEFAULT, to='meleager.language'),
        ),
        migrations.AddField(
            model_name='description',
            name='last_editor',
            field=models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_description_last_editor', related_query_name='meleager_descriptions_last_editor', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='commenttextanchor',
            name='text',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='meleager.text'),
        ),
        migrations.AddField(
            model_name='comment',
            name='descriptions',
            field=models.ManyToManyField(help_text='The multilingual descriptions for this object.', related_name='meleager_comment', related_query_name='meleager_comments', to='meleager.Description'),
        ),
        migrations.AddField(
            model_name='comment',
            name='images',
            field=models.ManyToManyField(blank=True, help_text='The images associated to this resource.', related_name='comments', to='meleager.Medium'),
        ),
        migrations.AddField(
            model_name='comment',
            name='last_editor',
            field=models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_comment_last_editor', related_query_name='meleager_comments_last_editor', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='city',
            name='descriptions',
            field=models.ManyToManyField(help_text='The multilingual descriptions for this object.', related_name='meleager_city', related_query_name='meleager_citys', to='meleager.Description'),
        ),
        migrations.AddField(
            model_name='city',
            name='last_editor',
            field=models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_city_last_editor', related_query_name='meleager_citys_last_editor', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='city',
            name='names',
            field=models.ManyToManyField(help_text='The multilingual names for this object.', related_name='cities', to='meleager.Name'),
        ),
        migrations.AddField(
            model_name='book',
            name='descriptions',
            field=models.ManyToManyField(help_text='The multilingual descriptions for this object.', related_name='meleager_book', related_query_name='meleager_books', to='meleager.Description'),
        ),
        migrations.AddField(
            model_name='book',
            name='last_editor',
            field=models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_book_last_editor', related_query_name='meleager_books_last_editor', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='book',
            name='work',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='meleager.work'),
        ),
        migrations.AddField(
            model_name='authorpassage',
            name='passage',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='meleager.passage'),
        ),
        migrations.AddField(
            model_name='authorpassage',
            name='user',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='author',
            name='alternative_urns',
            field=models.ManyToManyField(to='meleager.URN'),
        ),
        migrations.AddField(
            model_name='author',
            name='city_born',
            field=models.ForeignKey(blank=True, help_text='The city where this author was born.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='authors_born_at', related_query_name='meleager_authors_city_born', to='meleager.city'),
        ),
        migrations.AddField(
            model_name='author',
            name='city_died',
            field=models.ForeignKey(blank=True, help_text='The city where this author died.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='authors_died_at', to='meleager.city'),
        ),
        migrations.AddField(
            model_name='author',
            name='creator',
            field=models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_author_creator', related_query_name='meleager_authors_creator', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='author',
            name='descriptions',
            field=models.ManyToManyField(help_text='The multilingual descriptions for this object.', related_name='meleager_author', related_query_name='meleager_authors', to='meleager.Description'),
        ),
        migrations.AddField(
            model_name='author',
            name='images',
            field=models.ManyToManyField(blank=True, help_text='The images associated to this resource.', related_name='authors', to='meleager.Medium'),
        ),
        migrations.AddField(
            model_name='author',
            name='last_editor',
            field=models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_author_last_editor', related_query_name='meleager_authors_last_editor', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='author',
            name='names',
            field=models.ManyToManyField(help_text='The multilingual names for this object.', related_name='authors', to='meleager.Name'),
        ),
        migrations.CreateModel(
            name='Alignment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('unique_id', models.IntegerField(blank=True, db_index=True, unique=True)),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('validation', models.IntegerField(choices=[(0, 'Validation level 0, see ValidationLevelName.validation_level = 0 for the validation level name.'), (1, 'Validation level 1, see ValidationLevelName.validation_level = 1 for the validation level name.')], default=0, help_text='The current validation level of this resource.')),
                ('alignment_data', django_extensions.db.fields.json.JSONField(default=dict, help_text='The alpheios alignment json.')),
                ('creator', models.ForeignKey(help_text='The creator of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_alignment_creator', related_query_name='meleager_alignments_creator', to=settings.AUTH_USER_MODEL)),
                ('last_editor', models.ForeignKey(help_text='The last editor of this resource.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='meleager_alignment_last_editor', related_query_name='meleager_alignments_last_editor', to=settings.AUTH_USER_MODEL)),
                ('text_1', models.ForeignKey(blank=True, help_text='The first text, if null, the text is missing (deleted)', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='meleager_alignment_text_1', related_query_name='meleager_alignments_text_1', to='meleager.text')),
                ('text_2', models.ForeignKey(blank=True, help_text='The second text, if null, the text is missing (deleted)', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='meleager_alignment_text_2', related_query_name='meleager_alignments_text_2', to='meleager.text')),
            ],
            options={
                'permissions': [('set_validation_level_0', 'The permission to set validation level 0, see ValidationLevelName.validation_level = 0 for the validation level name.'), ('set_validation_level_1', 'The permission to set validation level 1, see ValidationLevelName.validation_level = 1 for the validation level name.')],
                'abstract': False,
            },
        ),
        migrations.AddConstraint(
            model_name='textpassage',
            constraint=models.UniqueConstraint(fields=('text', 'passage'), name='unique association between text and passage'),
        ),
        migrations.AddConstraint(
            model_name='authorpassage',
            constraint=models.UniqueConstraint(fields=('author', 'passage'), name='unique association between author and passage'),
        ),
    ]
